@@ -29,7 +29,12 @@ class KeySeq(Module):
 
     key: tp.Union[types.Initializer, jnp.ndarray] = types.Rng.node()
 
-    def __init__(self, key: tp.Optional[tp.Union[jnp.ndarray, int]] = None):
+    def __init__(
+        self,
+        key: tp.Optional[tp.Union[jnp.ndarray, int]] = None,
+        *,
+        axis_name: tp.Optional[tp.Any] = None
+    ):
         """
         Arguments:
             key: An optional PRNGKey to initialize the KeySeq with.
@@ -42,14 +47,25 @@ class KeySeq(Module):
             if isinstance(key, (jnp.ndarray, np.ndarray))
             else types.Initializer(lambda key: key)
         )
+        self.axis_name = axis_name
 
-    def __call__(self) -> jnp.ndarray:
+    def __call__(self, *, axis_name: tp.Optional[tp.Any] = None) -> jnp.ndarray:
         """
         Return a new PRNGKey and updates the internal rng state.
 
         Returns:
             A PRNGKey.
         """
+        key: jnp.ndarray
+
         assert isinstance(self.key, jnp.ndarray)
         key, self.key = utils.iter_split(self.key)
+
+        if axis_name is None:
+            axis_name = self.axis_name
+
+        if axis_name is not None:
+            axis_index = jax.lax.axis_index(axis_name)
+            key = jax.random.fold_in(key, axis_index)
+
         return key
